locfit.raw is an interface to Locfit using numeric vectors
(for a model-formula based interface, use locfit).
Although this function has a large number of arguments, most users
are likely to need only a small subset. The first set of arguments (x, y, weights,
cens, and base) specify the regression
variables and associated quantities.
Another set (scale, alpha, deg, kern,
kt, acri and basis) control the amount of smoothing:
bandwidth, smoothing weights and the local model.
deriv and dc relate to derivative (or local slope)
estimation.
family and link specify the likelihood family.
xlim and renorm may be used in density estimation.
ev, flim, mg and cut
control the set of evaluation points.
maxk, itype, mint, maxit and debug
control the Locfit algorithms, and will be rarely used.
geth and sty are used by other functions calling
locfit.raw, and should not be used directly.
locfit.raw(x, y, weights=1, cens=NULL, base=0,
scale=FALSE, alpha=0.7, deg=2, kern="tricube", kt="sph", acri="none",
basis=list(NULL), deriv=numeric(0), dc=FALSE,
family, link="default", xlim, renorm=FALSE,
ev="tree", flim, mg=10, cut=0.8,
maxk=100, itype="default", mint=20, maxit=20, debug=0,
geth=FALSE, sty=rep(1,d))y can be omitted.1 (or TRUE) for a censored observation, and
0 (or FALSE) for uncensored observations.basang terms. If alpha=0.7)
is interpreted as a nearest neighbor fraction. With two
componentes (e.g. alpha=c(0.7,1.2)), the first component
is a nearest neighbor fraction, and the second component is
a "tcub".
Other choices are "rect", "trwt", "tria",
"epan", "bisq" and "gauss". Choices may be restricted
when derivatives are requir"sph" (default); "prod".
In multivariate problems, "prod" uses a
simplified product model which speeds up computations.lfbas for more details on this argument.deriv=1, the returned fit will be
estimating the derivative (or more correctly, an estimate of the
local slope). If deriv=c(1,1) the second order derivative
is estimated. deriv=2 is fo"gaussian";
"binomial"; "poisson"; "gamma" and "geom".
Density and rate estimation families are "dens", "rate" and
"hazard""ident", "log", "logit",
"inverse", "sqrt" and "arcsin".c(ll,ul) where ll is a vector of
the lower bounds and ur renorm=T, the integral will be estimated
numerically and the estimate rescaled. Presently this is implemented
only in one dimension."tree". Also available are
"phull", "data", "grid", "kdtree",
"kdcenter" and "crossval". ev="none" gives no
evaluc(ll,ur). This should not be confused with
xlim. It defaults to the data range."grid" evaluation structure, mg specifies the
number of points on each margin. Default 10. Can be either a single
number or vector."prod", "mult" and "mlin"; and "haz" for
hazard rate estimation problems. The available integration methods
depend on model specif